// Graph for SpXZeigR
// Jeffrey J Weimer
// This works with SpXZeigR 4.1x
// Revision History: $Revision: $ on $Date: $

#pragma rtGlobals=1
#pragma IgorVersion=6.03
#pragma version=4.10

#pragma ModuleName=SpXZeigRGraph

// REQUIRED External Packages

#include "LinkDisplay"

// Constants

Static Constant kGLeft = 0
Static Constant kGTop = 0
Static Constant kGRight = 60
Static Constant kGBottom = 60

Static STRUCTURE GraphPanelStructure

	variable gpw
	variable gph
	
ENDSTRUCTURE

Static Function GraphPanelInit(xzGPS)
	STRUCT GraphPanelStructure &xzGPS
	
	xzGPS.gpw=175
	xzGPS.gph=300
	
	return 0
end

// Display Spectra

Static Function DisplaySpectra()
	
	// initialize new panel, graph, and screen sizes
	
	STRUCT GraphPanelStructure xzGPS
	GraphPanelInit(xzGPS)
	
	// get display parameters
	
	SVAR dff = root:Packages:SpXZeigR:DisplayPanel:displayfromfolder
	SVAR wtd = root:Packages:SpXZeigR:DisplayPanel:displaywavelist
	NVAR ngr = root:Packages:SpXZeigR:Globals:ngraphs
	NVAR dmt = root:Packages:SpXZeigR:DisplayPanel:displaymultitrace
	
	variable ic=1, nt, flag=0
	
	string cdf = GetDataFolder(1), wdf="root:",theWave
	string theGraph = WinList("*",";","WIN:1")
	string theTopGraph="", theFlags
	
	if (cmpstr(dff,"root")!=0)
		wdf += dff + ":"
	endif
	
	SetDataFolder $wdf
	
	if (strlen(theGraph)==0)
		ngr = 1
	else
		theTopGraph = StringFromList(ItemsInList(theGraph)-1,theGraph)
	endif
		
	nt = ItemsInList(wtd)
	
	for(ic=0;ic<nt;ic+=1)
		theWave = StringFromList(ic,wtd)
		theGraph = "SpXZeigR Plot " + num2str(ngr)
		switch(ic)
			case 0:
				if ((dmt == 2) && (ngr > 1))
					DoWindow/F theTopGraph
					LinkDisplay#lappendtograph(theWave)
					flag = 1
				else
					LinkDisplay#ldisplay(theWave,title=theGraph)
					GraphSetup()
				endif
				break
			default:
				if (dmt < 3)
					LinkDisplay#lappendtograph(theWave)
				else
//					xzGraphFinalize(spt,grm)
//					xzGraphPanelShow(psfw, psfh)
					LinkDisplay#ldisplay(theWave,title=theGraph)
					GraphSetup()
				endif
			endswitch
	endfor
//	xzGraphFinalize(spt,grm)
	if (!flag)
//		xzGraphPanelShow(psfw, psfh)
	endif
	
	SetDataFolder $cdf
	return 0
end

// set up the graph

Static Function GraphSetup()
	
	NVAR ngr = root:Packages:SpXZeigR:Globals:ngraphs

	SVAR dfGraphMode = root:Packages:SpXZeigR:Graphs:GraphModes:defaultGraphMode
	
	string rootFldr = "root:Packages:SpXZeigR:Graphs:GraphModes:" + dfGraphMode
	
	SVAR textdefaults = $(rootFldr + ":textdefaults")
	SVAR axesbottom = $(rootFldr + ":axes:bottom")
	SVAR axesleft = $(rootFldr + ":axes:left")

	string theCmd, theItem, theICmd
	variable ic, nt, theNum
	
	//astr0, astr1, astr, dfustr
	
	// axes format
	
	ScreenSizer#MoveFrontWindow(kGLeft+ngr,kGTop+ngr,kGRight+ngr,kGBottom+ngr)

	sprintf theCmd, "DefaultFont/U \"%s\"" StringByKey("font",textdefaults,"=")
	Execute/Q theCmd
	ModifyGraph fSize=(NumberByKey("AxesLabelSizes",textdefaults,"="))
	
	nt = ItemsInList(axesbottom)
	theCmd = "ModifyGraph"
	for(ic=0;ic<nt;ic+=1)
		SplitString/E="(.+)=.+" StringFromList(ic,axesbottom), theItem
		if (strlen(theItem)!=0)
			theNum = NumberByKey(theItem,axesbottom,"=")
			if (numtype(theNum)==0)
				sprintf theCmd, "%s %s(bottom)=%d,", theCmd, theItem, theNum
			endif
		endif
	endfor
	theCmd = RemoveEnding(theCmd)
	Execute/Q theCmd

	nt = ItemsInList(axesleft)
	theCmd = "ModifyGraph"
	for(ic=0;ic<nt;ic+=1)
		SplitString/E="(.+)=.+" StringFromList(ic,axesleft), theItem
		if (strlen(theItem)!=0)
			theNum = NumberByKey(theItem,axesleft,"=")
			if (numtype(theNum)==0)		
				sprintf theCmd, "%s %s(left)=%d,", theCmd, theItem, theNum
			endif
		endif
	endfor
	theCmd = RemoveEnding(theCmd)
	Execute/Q theCmd
	
//	ModifyGraph mirror=2,fSize=xzDefaultAxesLabelSize
//	
//	// axes labels
//	
//	sprintf astr0, "\\Z%g\\[0%s", xzDefaultAxesLabelSize, xzGetSpectrumTypeParam(type,"ylabel")
//	dfustr =  xzGetSpectrumTypeParam(type,"yunits")
//	if (strlen(dfustr)==0)
//		sprintf astr1, "\M %s\u\M%s",xzDefaultGraphUnitEnvelope[0],xzDefaultGraphUnitEnvelope[1]
//	else
//		sprintf astr1, "\M %s%s\M%s",xzDefaultGraphUnitEnvelope[0],dfustr,xzDefaultGraphUnitEnvelope[1]
//	endif
//	astr = astr0 + astr1
//	Label left astr
//	sprintf astr0, "\\Z%g\\[0%s", xzDefaultAxesLabelSize, xzGetSpectrumTypeParam(type,"xlabel")
//	dfustr =  xzGetSpectrumTypeParam(type,"xunits")
//	if (strlen(dfustr)==0)
//		sprintf astr1, "\M %s\u\M%s",xzDefaultGraphUnitEnvelope[0],xzDefaultGraphUnitEnvelope[1]
//	else
//		sprintf astr1, "\M %s%s\M%s",xzDefaultGraphUnitEnvelope[0],dfustr,xzDefaultGraphUnitEnvelope[1]
//	endif
//	astr = astr0 + astr1
//	Label bottom astr
	ngr+=1
	
	DoUpdate
	return 0
end

//// finalize the graph
//
//Static Function xzGraphFinalize(type,pm)
//	variable type, pm
//	
//	string trm, tr, sclstr
//	variable nit, ic, pp, scl=0
//
//	// autoscaling
//	
//	trm = xzGetGraphModeParam(pm,"autoscale")
//	strswitch(trm)
//		case "on":
//			SetAxis/A
//			sclstr = xzGetSpectrumTypeParam(type,"xscaling")
//			if (cmpstr(sclstr,"normal")!=0)
//				SetAxis/A/R bottom
//				scl=-1
//			endif
//			sclstr = xzGetSpectrumTypeParam(type,"yscaling")
//			if (cmpstr(sclstr,"normal")!=0)
//				SetAxis/A/R left
//			endif
//			break
//		case "off":
//			GetAxis/Q bottom
//			sclstr = xzGetSpectrumTypeParam(type,"xscaling")
//			if (cmpstr(sclstr,"normal")!=0)
//				SetAxis bottom V_max, V_min
//				scl=-1
//			else
//				SetAxis bottom V_min, V_max
//			endif
//			GetAxis/Q left
//			sclstr = xzGetSpectrumTypeParam(type,"yscaling")
//			if (cmpstr(sclstr,"normal")!=0)
//				SetAxis left V_max, V_min
//			else
//				SetAxis left V_min, V_max
//			endif
//			break
//		case "nice":
//			sclstr = xzGetSpectrumTypeParam(type,"xscaling")
//			if (cmpstr(sclstr,"normal")!=0)
//				SetAxis/A/R bottom
//			endif
//			sclstr = xzGetSpectrumTypeParam(type,"yscaling")
//			if (cmpstr(sclstr,"normal")!=0)
//				SetAxis/A/R/N=2 left
//				scl=-1
//			endif
//			break
//	endswitch
//	
//	// trace mode
//		
//	trm = xzGetGraphModeParam(pm,"tracemode")
//	strswitch(trm)
//		case "lines":
//			ModifyGraph mode=0
//		break
//		case "dots":
//			ModifyGraph mode=3,marker=19,msize=1
//		break
//	endswitch
//	
//	// show title
//	
//	sprintf trm, "\\Z%g\\[0%s", xzDefaultGraphTitleSize, xzGetSpectrumTypeParam(type,"title")
//	if (cmpstr(xzGetGraphModeParam(pm,"showtitle"),"TRUE")==0)
//		TextBox/C/N=Title/F=0/A=LT trm
//	else
//		TextBox/K/N=Title
//	endif
//	
//	// tag traces
//
//	trm =  TraceNameList("",";",1)
//	nit = ItemsInList(trm)
//	for (ic=0;ic<nit;ic+=1)
//		tr = StringFromList(ic,trm,";")
//		if (cmpstr(xzGetGraphModeParam(pm,"tagtraces"),"TRUE")==0)
//			if (scl<0)
//				pp = numpnts(TraceNametoWaveRef("",tr))-6
//			else
//				pp = 5
//			endif
//			Tag/C/N=$("tag" + num2str(ic))/F=0/A=LB/L=1 $tr, pp,"\\ON"
//		else
//			Tag/K/N=$("tag" + num2str(ic))	
//		endif
//	endfor
//	
//	// trace colors
//	
//	ModifyGraph rgb=(0,0,0)
//	
//	DoUpdate	
//	return 0
//end
//
//// graph panel
//
//Static Function xzGraphPanelShow(psfw,psfh)
//	variable psfw, psfh
//
//	NewPanel/EXT=0/HOST=#/K=1/N=xzGraph/W=(0,0.5,psfw,0) as "Graph"
////	ModifyPanel noEdit=1
//
//
//	// tab
//	
//	TabControl tb,pos={1,2},size={70,20}
//	TabControl tb, tabLabel(0)="Graph",value= 0
//
//	// title
//	
//	TitleBox title,pos={20,30},size={169,17},title="SpXZeigR Graph Panel",fSize=14
//	TitleBox title,frame=0,fStyle=1
//	return 0
//end
