// SpXZeigR StartUp
// Routines for SpXZeigR 4.1x
// Jeffrey J Weimer
// SVN History: $Revision: 828 $ on $Date: 2008-07-08 17:00:47 -0500 (Tue, 08 Jul 2008) $

#pragma rtGlobals=1
#pragma IgorVersion=6.03
#pragma version=4.10

#pragma ModuleName=SpXZeigRStartUp

// REQUIRED External Packages

#include "ScreenSizer"
#include "udStFiLrXML"

// SpXZeigR Procedure Files

#include "SpXZeigR.lcl"
#include "SpXZeigRMenus"
#include "SpXZeigRShutDown"
#include "SpXZeigRPanel"
//#include "SpXZeigRCommonFunctions" version >= 4.00
//#include "SpXZeigRListFunctions" version >= 4.00
//#include "SpXZeigRFileLoader" version >= 4.00
//#include "SpXZeigRGraph" version >= 4.00

// LOCAL CONSTANTS

//StrConstant SpXZDTStr="%date();%time();"
//StrConstant SpXZLogOp="SpXZeigRLogOp"

// start up / restart function

Static Function StartUp()

	variable winXX
	string cdf, hstr, theCmd
	
	cdf = GetDataFolder(1)
	
	// create the package folder
	
	if (DataFolderExists("root:Packages:SpXZeigR")==0)
	
		// initalize from clean start
		
		NewDataFolder/O/S root:Packages
		NewDataFolder/O SpXZeigR
		hstr =  "Started"
		winXX = 1
	else
	
		// restart
		
		hstr =  "(re)Started"
		winXX = 0
	endif

	// Set Up SpXZeigR
	
	CreateSpXZeigRPackage()
	LoadSpXZeigRPreferences()
	
	// organize the GUI
	
	RedrawScreen(winXX)
	
	SetDataFolder $cdf
//	xzPrintHistory("note",hstr)
	return 0
end

Static Function RedrawScreen(winXX)
	variable winXX
	
	SettheScreenParadigm(winXX)
	SettheLoadersParadigm()
	SpXZeigRPanel#ShowSpXZeigRPanel()

	return 0
end

Static Function ChangeSpXZeigRParadigm()

	string theOne="", theList=""
	string theDir = "root:Packages:SpXZeigR:Paradigms"
	variable pc=0, ic=0
	
	SVAR dP = root:Packages:SpXZeigR:Paradigms:defaultParadigm
	
	do
		theOne = GetIndexedObjName(theDir,4,ic)
		if (strlen(theOne)==0)
			break
		endif
		theList += theOne + ";"
		ic += 1
	while(1)
	
	pc = 0
	ic = 0
	prompt pc, "Select the paradigm", popup, theList
	prompt ic, "Resize the Windows frame?", popup, "Yes;No;"
	if (cmpstr(IgorInfo(2),"Macintosh")==0)
		DoPrompt "Paradigm Shift", pc
		ic = 1
	else
		DoPrompt "Paradigm Shift", pc, ic
	endif
	if (!V_flag)
		dP = StringFromList(pc-1,theList)
		SettheScreenParadigm(ic)
		SettheLoadersParadigm()
		SpXZeigRPanel#ShowSpXZeigRPanel()
	endif
	
	return 0
end

// LOCAL UTILITY FUNCTIONS

Static Function CreateSpXZeigRPackage()

	// globals
	
	NewDataFolder/O/S root:Packages:SpXZeigR:Globals
	variable/G started=1, ngraphs=0
//	string/G pathdata="", pathstorage="", verbose=""
//	string/G tStr=""

	// graph parameters
	
	NewDataFolder/O/S root:Packages:SpXZeigR:Graphs
//	string/G wavestodisplay=""
//	variable/G spectrumtype=1, graphmode=1, ngraphs=0

	NewDataFolder/O/S root:Packages:SpXZeigR:DisplayPanel
	
	string/G displayfromfolder="root"
	string/G displaywavelist="", displaywildcard=""
	variable/G displaymultitrace=1, displaylinked=0

	return 0
end

// set the spectra parameters

Static Function LoadSpXZeigRPreferences()

	STRUCT udFLStandardStructure udFL
	udFLZeroStructure(udFL)

	string tmpStr
	variable tmpN
				
	// load the defaults
	
	tmpStr = FunctionPath("")
	tmpN = ItemsInList(tmpStr,":")
	
	tmpStr = RemoveListItem(tmpN-1,tmpStr,":")
	tmpStr = RemoveListItem(tmpN-2,tmpStr,":")
	
	udFL.pathStr = tmpStr + "XMLFiles:"
	udFL.fileList = "preferences.xsl;DEFAULTpreferences.xml;"

	udFL.userLCtrl = 1
	udFL.toFolder = ""
	udFL.reportCtrl = -1
	udStFiLrXML(udFL)
	
	// load the user defined

	udFL.pathStr = ""
	udFL.fileList = tmpStr + "XMLFiles:preferences.xsl;"
	udFL.fileList += tmpStr + "localizations:preferences.xml"

	udFL.userLCtrl = 1
	udFL.toFolder = ""
	udFL.reportCtrl = -1
	udStFiLrXML(udFL)
	
	SetDataFolder root:
	
	return 0
end

Static Function SettheScreenParadigm(winXX)
	variable winXX
	
	string theP
	variable left, top, right, bottom
	
	SVAR dP = root:Packages:SpXZeigR:Paradigms:defaultParadigm
	
	sprintf theP, "root:Packages:SpXZeigR:Paradigms:%s:screen", dP
	
	SVAR paradigm = $theP
	
	left = NumberByKey("left",paradigm,"=")
	top = NumberByKey("top",paradigm,"=")
	right = NumberByKey("right",paradigm,"=")
	bottom = NumberByKey("bottom",paradigm,"=")
	
	ScreenSizer#Initialize(winXX)
	ScreenSizer#SetFrame(left,top,right,bottom)
	ScreenSizer#MoveCmdWindow(2,80,60,10)
	return 0
end

Static Function SettheLoadersParadigm()
	
	string theP, theStr, theLoader, theCmd
	variable ic, nt
	
	SVAR dP = root:Packages:SpXZeigR:Paradigms:defaultParadigm
	
	sprintf theP, "root:Packages:SpXZeigR:Paradigms:%s:fileloaders", dP

	SVAR theLoadList = $theP
	
	nt = ItemsInList(theLoadList)
	for (ic=0;ic<nt;ic+=1)
		theStr = StringFromList(ic,theLoadList)
		SplitString/E="loader=(.+)" theStr, theLoader
		sprintf theCmd, "INSERTINCLUDE \"%s\"", theLoader
		Execute/P/Q/Z theCmd
	endfor
	
	Execute/P/Q/Z "COMPILEPROCEDURES "
	return 0

end

//// set the graph parameters
//
//Static Function SettheGraphParams()
//
//	NewDataFolder/O/S GraphParams
//	
//	variable/G spectrumtype=1, graphmode=1, ngraphs=0
//	string/G wavestodisplay=""
//	
//	NewDataFolder/O SpectrumTypes
//	InitSpectrumTypes()
//
//	NewDataFolder/O/S GraphModes
//	DefaultFont/U $xzDefaultGraphFont
//	SetDataFolder ::
//
//	SetDataFolder ::
//	return 0
//End

// set the display panel parameters
//
//Static Function SettheDisplayPanelParams()
//
//	SVAR dT = root:Packages:SpXZeigR:GraphParams:SpectrumTypes:defaultType
//
//	NewDataFolder/O/S DisplayPanelParams
//	
//	string/G displayfromfolder="root", displaywavename=""
//	string/G displaywavelist="", displaywildcard=""
//	variable/G displaymultitrace=1
//	string/G initialDisplayPanelMode=""
//	
//	// initialize the opening state of the display panel
//	
////	xzInitDisplayPanelMode()
//	
//	initialDisplayPanelMode += "spectrumtype=" + dT +";"
//
//	SetDataFolder ::
//	return 0
//End

Static Function LoadXMLTemplate()
	
//	STRUCT udFLStandardStructure udFL
//	udFLZeroStructure(udFL)

//	string theFile, tmpStr
//	variable tmpN
//				
//	// load the defaults
//	
//	tmpStr = FunctionPath("")
//	tmpN = ItemsInList(tmpStr,":")
//	
//	tmpStr = RemoveListItem(tmpN-1,tmpStr,":")
//	tmpStr = RemoveListItem(tmpN-2,tmpStr,":")
//	
//	sprintf theFile, "%sXMLFiles:SpXZeigRLogOpTemplate.xml", tmpStr
//	NT_LoadXMLTemplate("SpXZeigRLogOp",filename=theFile)
	return 0
end

Static Function xzModifyBrowser()

//	string brCmd, theStr = "xzModifyWaveNote(%s)"
//	brCmd = "CreateBrowser"
//	Execute/Q/Z brCmd
//	brCmd = "ModifyBrowser userlevel=8"
//	Execute/Q/Z brCmd
//	sprintf brCmd, "ModifyBrowser userMenu=\"Modify Note\", userMenuCommand=\"%s\"", theStr
//	Execute/Q/Z brCmd
//	brCmd = "ModifyBrowser echoCommands=0"
//	Execute/Q/Z brCmd
//	brCmd = "ModifyBrowser close"
//	Execute/Q/Z brCmd
	return 0
end

// LOCAL SUPPORT FUNCTIONS

//	string lStr, tmpStr
//	variable tmpN
//			
//	// load the default paradigm
//	
//	tmpStr = FunctionPath("")
//	tmpN = ItemsInList(tmpStr,":")
//	
//	tmpStr = RemoveListItem(tmpN-1,tmpStr,":")
//	tmpStr = RemoveListItem(tmpN-2,tmpStr,":")
//	
//	udFL.pathStr = tmpStr + "XMLFiles:"
//	udFL.fileList = "preferences.xsl;DEFAULTpreferences.xml;"
//
//	udFL.userCtrl = 1
//	udFL.toFolder = "Packages:SpXZeigR:Globals"
//	udFL.reportCtrl = -1
//	udStFiLrXML(udFL)
//	
//	// load the user defined paradigm
//
//	udFL.pathStr = ""
//	udFL.fileList = tmpStr + "XMLFiles:preferences.xsl;"
//	udFL.fileList += tmpStr + "localizations:preferences.xml"
//
//	udFL.userCtrl = 1
//	udFL.toFolder = "Packages:SpXZeigR:Globals"
//	udFL.reportCtrl = -1
//	udStFiLrXML(udFL)
//	
//	SVAR xStr = defaultParadigm
//	lStr = "Paradigm" + xStr
//	SVAR tStr = $lStr
//	
//	// store the path settings and verbose mode
//	
//	xzpathstorage = StringByKey("pathstorage",tStr,"=")
//	xzpathdata = StringByKey("pathdata",tStr,"=")
//	xzverbose = StringByKey("verbose",tStr,"=")
//	
//	// store the screen settings
//	
//	variable scrleft, scrtop, scrright, scrbottom
//
//	scrleft = NumberByKey("screenleft",tStr,"=")
//	scrtop = NumberByKey("screentop",tStr,"=")
//	scrright = NumberByKey("screenright",tStr,"=")
//	scrbottom = NumberByKey("screenbottom",tStr,"=")
//	
//	ScreenSizer#SetFrame(scrleft,scrtop,scrright,scrbottom)
//	
//	// return
//	
	
//	return 0

//end
